{% extends '_skeleton.jinja' %}

{% block predict %}
    return dot(x, {{ f.to_array(coefs) }}) + {{ intercept }};
{% endblock %}

{% block protected %}
    {% with expr = 'x[i] * wi' %}
        {% include 'dot.jinja' %}
    {% endwith %}
{% endblock %}