{% if left[i] != right[i] %}
    if (x[{{ features[i] }}] <= {{ thresholds[i] }}) {
        {% with i = left[i] %}
            {% include 'decisiontree/tree.jinja' %}
        {% endwith %}
    }
    else {
        {% with i = right[i] %}
            {% include 'decisiontree/tree.jinja' %}
        {% endwith %}
    }
{% else %}
    return {{ classes[i].argmax() }};
{% endif %}