#pragma once
#include <cstdarg>

namespace Eloquent {
    namespace ML {
        namespace Port {
            class {{ classname }} {
                public:

                    /**
                     * Predict class for features vector
                     */
                    {{ dtype|default("int", true) }} predict(float *x) {
                        {% block predict %}{% endblock %}
                    }

                    {% include 'classmap.jinja' %}

                    {% block public %}{% endblock %}

                protected:

                    {% block protected %}{% endblock %}
            };
        }
    }
}