{% extends '_skeleton.jinja' %}

{% block predict %}
    float votes[{{ classes|length }}] = { 0.0f };

    {% include 'logisticregression/vote.%s.jinja' % platform %}
    {% include 'vote.jinja' %}
{% endblock %}

{% block protected %}
    {% with dimension = weights[0]|length, expr = 'x[i] * wi' %}
        {% include 'dot.jinja' %}
    {% endwith %}
{% endblock %}