{% extends '_skeleton.jinja' %}

{% block predict %}
    uint8_t votes[{{ n_classes }}] = { 0 };

    {% for k, tree in f.enumerate(trees) %}
        {% with i = 0 %}
            // tree #{{ k + 1 }}
            {% include 'randomforest/tree.jinja' %}
        {% endwith %}
    {% endfor %}

    {% include 'vote.jinja' %}
{% endblock %}