const float {{ op }}LUT[{{ size }}][{{ fft.original_size }}] = {
    {% for i in range(0, size) %}
        { {% for n in range(0, fft.original_size) %} {{ math[op](2 * PI / fft.original_size * fft.idx[i] * n) }}, {% endfor %} },
    {% endfor %}
};