/**
 * Compute kernel between feature vector and support vector.
 * Kernel type: {{ kernel['type'] }}
 */
float compute_kernel(float *x, float w[{{ sizes.features }}]) {
    {% with %}
        {% set wi = 'w[i]' %}
        {% include 'svm/kernel/kernel.jinja' %}
    {% endwith %}
}