ARDUINO = 'arduino'
ATTINY = 'attiny'
ALL = [
    ARDUINO,
    ATTINY
]

ALLOWED_CLASSIFIERS = [
    'SVC',
    'LinearSVC',
    'OneClassSVC',
    'RVC',
    'SEFR',
    'DecisionTree',
    'RandomForest',
    'GaussianNB',
    'LogisticRegression',
    'PCA',
    'PrincipalFFT',
    'LinearRegression',
    'XGBClassifier'
]